;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "minions" "20251101.2032"
  "A minor-mode menu for the mode line."
  '((emacs  "26.1")
    (compat "30.1"))
  :url "https://github.com/tarsius/minions"
  :commit "7bd15dd0a12e898db6b24b03d4aa797f525fb0e8"
  :revdesc "7bd15dd0a12e"
  :keywords '("convenience")
  :authors '(("Jonas Bernoulli" . "emacs.minions@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.minions@jonas.bernoulli.dev")))
